# Acknowledgements

We sincerely thank the authors of following open-source projects:

- [PyTorch](https://github.com/pytorch/pytorch)
- [Transformers](https://github.com/huggingface/transformers)
- [Datasets](https://github.com/huggingface/datasets)
- [Accelerate](https://github.com/huggingface/accelerate)
- [Scanpy](https://github.com/scverse/scanpy)
- [cell-eval](https://github.com/ArcInstitute/cell-eval)
- [STATE](https://github.com/ArcInstitute/state)
- [scGPT](https://github.com/bowang-lab/scGPT/tree/main)
- [EpiAgent](https://github.com/xy-chen16/EpiAgent)
- [GEARS](https://github.com/snap-stanford/GEARS)
- [wppkg](https://github.com/Peg-Wu/wppkg)